@@ -46,18 +46,55 @@ add_overall.tbl_summary <- function(x, last = FALSE, col_label = NULL) {
   x_copy$inputs[["by"]] <- NULL
 
   # calculating stats overall, and adding header row
-  overall <-
-    do.call(tbl_summary, x_copy$inputs) %>%
-    pluck("table_body")
+  tbl_overall <- do.call(tbl_summary, x_copy$inputs)
 
-  x <- add_overall_merge(x, overall, last, col_label)
+  # merging overall results
+  x <- add_overall_merge(x, tbl_overall, last, col_label)
 
   x$call_list <- updated_call_list
   x
 }
 
 
-add_overall_merge <- function(x, overall, last, col_label) {
+#' @rdname add_overall
+#' @export
+add_overall.tbl_svysummary <- function(x, last = FALSE, col_label = NULL) {
+  updated_call_list <- c(x$call_list, list(add_overall = match.call()))
+  # checking that input x has a by var
+  if (is.null(x$inputs[["by"]])) {
+    stop(
+      "Cannot add Overall column when no 'by' variable in original tbl_svysummary"
+    )
+  }
+
+  x_copy <- x
+
+  # removing 'by' variable from data
+  # (so it won't show up in the overall tbl_summary)
+  x_copy$inputs$data$variables <- select(x$inputs$data$variables, -x$by)
+  x_copy$inputs$include <- x_copy$inputs$include %>% setdiff(x[["by"]])
+
+  # replacing the function call by variable to NULL to get results overall
+  x_copy$inputs[["by"]] <- NULL
+
+  # calculating stats overall, and adding header row
+  tbl_overall <- do.call(tbl_svysummary, x_copy$inputs)
+
+  # merging overall results
+  x <- add_overall_merge(x, tbl_overall, last, col_label)
+
+  x$call_list <- updated_call_list
+  x
+}
+
+
+
+add_overall_merge <- function(x, tbl_overall, last, col_label) {
+  # extracting table body from overall table
+  overall <-
+    tbl_overall %>%
+    pluck("table_body")
+
   # checking the original tbl_summary and the added overall,
   # are the same before binding (excluding headers)
   if (!identical(
@@ -72,6 +109,25 @@ add_overall_merge <- function(x, overall, last, col_label) {
       stop(call. = FALSE)
   }
 
+  # adding the stat_0 row to to the df_stats tibbles
+  x$meta_data$df_stats <-
+    x$meta_data$variable %>%
+    map(
+      function(.x) {
+        bind_rows(
+          x$meta_data$df_stats[[which(x$meta_data$variable %in% .x)]],
+          tbl_overall$meta_data$df_stats[[which(tbl_overall$meta_data$variable  %in% .x)]]
+        ) %>%
+          purrr::imap_dfc(
+            function(vec, colname) {
+              attributes(vec) <-
+                attributes(x$meta_data$df_stats[[which(x$meta_data$variable  %in% .x)]][[colname]])
+              vec
+            }
+          )
+      }
+    )
+
   # adding overall stat to the table_body data frame
   x$table_body <-
     bind_cols(
@@ -99,41 +155,8 @@ add_overall_merge <- function(x, overall, last, col_label) {
     modify_header(
       stat_0 =
         col_label %||%
-          paste0("**", translate_text("Overall"), "**, N = {style_number(N)}"),
+        paste0("**", translate_text("Overall"), "**, N = {style_number(N)}"),
     )
 
   x
 }
-
-
-#' @rdname add_overall
-#' @export
-add_overall.tbl_svysummary <- function(x, last = FALSE, col_label = NULL) {
-  updated_call_list <- c(x$call_list, list(add_overall = match.call()))
-  # checking that input x has a by var
-  if (is.null(x$inputs[["by"]])) {
-    stop(
-      "Cannot add Overall column when no 'by' variable in original tbl_svysummary"
-    )
-  }
-
-  x_copy <- x
-
-  # removing 'by' variable from data
-  # (so it won't show up in the overall tbl_summary)
-  x_copy$inputs$data$variables <- select(x$inputs$data$variables, -x$by)
-  x_copy$inputs$include <- x_copy$inputs$include %>% setdiff(x[["by"]])
-
-  # replacing the function call by variable to NULL to get results overall
-  x_copy$inputs[["by"]] <- NULL
-
-  # calculating stats overall, and adding header row
-  overall <-
-    do.call(tbl_svysummary, x_copy$inputs) %>%
-    pluck("table_body")
-
-  x <- add_overall_merge(x, overall, last, col_label)
-
-  x$call_list <- updated_call_list
-  x
-}
