@@ -14,15 +14,13 @@
 #' @return a ggplot
 #' @name plot
 #'
-#' @examples
-#' if (requireNamespace("GGally")) {
-#'   glm(response ~ marker + grade, trial, family = binomial) %>%
-#'     tbl_regression(
-#'       add_estimate_to_reference_rows = TRUE,
-#'       exponentiate = TRUE
-#'     ) %>%
-#'     plot()
-#' }
+#' @examplesIf assert_package("GGally", boolean = TRUE)
+#' glm(response ~ marker + grade, trial, family = binomial) %>%
+#'   tbl_regression(
+#'     add_estimate_to_reference_rows = TRUE,
+#'     exponentiate = TRUE
+#'   ) %>%
+#'   plot()
 NULL
 
 #' @rdname plot
@@ -30,7 +28,7 @@ NULL
 plot.tbl_regression <- function(x,
                                 remove_header_rows = TRUE,
                                 remove_reference_rows = FALSE, ...) {
-  assert_package("GGally", fn = "plot.tbl_regression()", version = "2.1.0")
+  assert_package("GGally", fn = "plot.tbl_regression()")
 
   df_coefs <- x$table_body
   if (isTRUE(remove_header_rows)) {
