@@ -1,6 +1,6 @@
 #' Creates table of survival probabilities
 #'
-#' \lifecycle{experimental}
+#' \lifecycle{maturing}
 #' Function takes a `survfit` object as an argument, and provides a
 #' formatted summary table of the results
 #'
@@ -35,7 +35,7 @@
 #' @rdname tbl_survfit
 #' @family tbl_survfit tools
 #' @author Daniel D. Sjoberg
-#' @examples
+#' @examplesIf assert_package("survival", boolean = TRUE)
 #' library(survival)
 #'
 #' # Example 1 ----------------------------------
@@ -121,9 +121,9 @@ tbl_survfit.list <- function(x, times = NULL, probs = NULL,
   # input checks ---------------------------------------------------------------
   if (rlang::is_string(label)) {
     label <- inject(everything() ~ !!label)
-    # lifecycle::deprecate_warn(
-    #   "1.3.6", "gtsummary::tbl_survfit(label=)",
-    #   details = "`label=` argument no longer accepts a single string. Pass formula list.")
+    lifecycle::deprecate_warn(
+      "1.3.6", "gtsummary::tbl_survfit(label=)",
+      details = "`label=` argument no longer accepts a single string. Pass formula list.")
   }
   assert_package("survival", "tbl_survfit()")
   if (purrr::every(x, ~ !inherits(.x, "survfit"))) {
@@ -317,14 +317,16 @@ meta_to_df_stats <- function(meta_data, inputs, estimate_type, estimate_fun,
             conf.level = inputs$conf.level,
             reverse = inputs$reverse,
             quiet = inputs$quiet, tidy = ..3,
-            var_label = ..4
+            var_label = ..4,
+            estimate_fun =  estimate_fun
           ),
           "probs" = survfit_prob(..1,
             variable = ..2, probs = inputs$probs,
             label_header = inputs$label_header,
             conf.level = inputs$conf.level,
             quiet = inputs$quiet, tidy = ..3,
-            var_label = ..4
+            var_label = ..4,
+            estimate_fun =  estimate_fun
           )
         )
       ),
@@ -375,7 +377,7 @@ meta_to_df_stats <- function(meta_data, inputs, estimate_type, estimate_fun,
 
 # calculates and prepares survival quantile estimates for tbl
 survfit_prob <- function(x, variable, probs, label_header, conf.level, quiet,
-                         tidy, var_label) {
+                         tidy, var_label, estimate_fun) {
   strata <- intersect("strata", names(tidy)) %>%
     list() %>%
     compact()
@@ -408,16 +410,24 @@ survfit_prob <- function(x, variable, probs, label_header, conf.level, quiet,
         "**{style_percent(prob, symbol = TRUE)} {translate_text('Percentile')}**" %>%
         glue() %>% as.character()
     )
+  if (length(strata) > 0) {
+    df_stat$variable_levels = df_stat$label
+  }
 
   # removing strata column if there are no stratum in survfit
   if (length(strata) == 0) df_stat <- select(df_stat, -.data$strata)
 
+  # add fmt_fun attribute
+  for (column in c("estimate", "conf.low", "conf.high")) {
+    attr(df_stat[[column]], "fmt_fun") <- estimate_fun
+  }
+
   df_stat
 }
 
 # calculates and prepares n-year survival estimates for tbl
 survfit_time <- function(x, variable, times, label_header, conf.level,
-                         reverse, quiet, tidy, var_label) {
+                         reverse, quiet, tidy, var_label, estimate_fun) {
   strata <- intersect("strata", names(tidy)) %>%
     list() %>%
     compact()
@@ -506,6 +516,9 @@ survfit_time <- function(x, variable, times, label_header, conf.level,
       any_of(c("variable", "label", "strata", "col_name", "col_label")),
       everything(), -.data$time_max
     )
+  if (length(strata) > 0) {
+    df_stat$variable_levels = df_stat$label
+  }
 
   # converting to reverse probs, if requested
   if (reverse == TRUE) {
@@ -515,6 +528,11 @@ survfit_time <- function(x, variable, times, label_header, conf.level,
       dplyr::rename(conf.low = .data$conf.high, conf.high = .data$conf.low)
   }
 
+  # add fmt_fun attribute
+  for (column in c("estimate", "conf.low", "conf.high")) {
+    attr(df_stat[[column]], "fmt_fun") <- estimate_fun
+  }
+
   df_stat
 }
 
