@@ -1,5 +1,4 @@
-context("test-modify_spanning_header")
-testthat::skip_on_cran()
+skip_on_cran()
 
 test_that("modify_spanning_header works", {
   expect_error(
@@ -22,7 +21,7 @@ test_that("modify_spanning_header works", {
   expect_true(
     tbl1 %>%
       modify_spanning_header(everything() ~ NA) %>%
-      purrr::pluck("table_header", "spanning_header") %>%
+      purrr::pluck("table_styling", "header", "spanning_header") %>%
       is.na() %>%
       all()
   )
