@@ -1,4 +1,4 @@
-context("test-show_header_names")
+skip_on_cran()
 
 test_that("show_header_names works", {
   expect_error(
